#include <iostream>
#include <vector>
#include <algorithm>
#include <random>

using namespace std;

typedef long long ll;

random_device rd;
mt19937 rng(rd());

struct rect {
    int no;
    ll a, b;
};

struct node {
    ll a, y;
    ll ab;
    ll maxp = 0;
    node *l, *r;
    node(ll a, ll y, ll ab) : a(a), y(y), ab(ab), l(nullptr), r(nullptr) {}
};
typedef node *pnode;

int maxp(pnode t) {
    return t ? t->maxp : 0;
}

void update(pnode t) {
    if (!t) return;
    t->maxp = max(maxp(t->l), maxp(t->r));
    t->maxp = max(t->maxp, t->ab);
}

void split(pnode t, ll a, pnode &l, pnode &r) {
    if (!t)
        l = r = nullptr;
    else if (a < t->a)
        split(t->l, a, l, t->l), r = t;
    else
        split(t->r, a, t->r, r), l = t;
    update(t);
}

void merge(pnode &t, pnode l, pnode r) {
    if (!l || !r)
        t = l ? l : r;
    else if (l->y > r->y)
        merge(l->r, l->r, r), t = l;
    else
        merge(r->l, l, r->l), t = r;
    update(t);
}

void insert(pnode &t, ll a, ll ab) {
    ll y = rng();
    pnode l, r;
    split(t, a, l, r);
    merge(t, l, new node(a, y, ab));
    merge(t, t, r);
}

int main() {

    int n;
    cin >> n;
    vector<rect> ra, rb;
    for (int i = 0; i < n; i++) {
        ll a, b;
        cin >> a >> b;
        ra.push_back({i, a, b});
        rb.push_back(ra.back());
    }

    sort(ra.begin(), ra.end(), [](rect &p1, rect &p2) {
        return p1.a == p2.a ? p1.b < p2.b : p1.a < p2.a;
    });
    sort(rb.begin(), rb.end(), [](rect &p1, rect &p2) {
        return p1.b == p2.b ? p1.a < p2.a : p1.b < p2.b;
    });
    vector<int> posa(n);
    vector<ll> sufa(n + 1), sufb(n + 1);
    sufa[n] = sufb[n] = -1;
    for (int i = n - 1; i > -1; i--) {
        posa[ra[i].no] = i;
        sufa[i] = max(sufa[i + 1], ra[i].b);
        sufb[i] = max(sufb[i + 1], rb[i].a);
    }

    pnode root = nullptr;
    vector<ll> result(n);
    for (int i = 0; i < n; i++) {
        ll res = 4'000'000'000ll;
        if (i < n - 1) {
            ll maxa_right = sufb[i + 1];
            res = min(res, max(0ll, rb[i].a - maxa_right));
        }
        if (posa[rb[i].no] < n - 1) {
            ll maxb_right = sufa[posa[rb[i].no] + 1];
            res = min(res, max(0ll, rb[i].b - maxb_right));
        }
        if (root) {
            pnode l, r;
            split(root, rb[i].a, l, r);
            if (l)
                res = min(res, rb[i].a + rb[i].b - l->maxp);
            merge(root, l, r);
        }
        insert(root, rb[i].a, rb[i].a + rb[i].b);
        result[rb[i].no] = res;
    }

    for (ll res : result)
        cout << res << ' ';
    cout << '\n';

}